# -*- Mode: Python; py-indent-offset: 4 -*-
# * Copyright (C) 2003 Nikolay Kim <fafhrd@legco.biz> 
"""
$Id: PermissionsManagement.py,v 1.8.4.1 2005/01/27 08:56:54 lalo Exp $
"""

from ExtensionClass import Base
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from AccessControl.Permission import Permission

from ForumPermissions import *

managedablePermissions = [ View, AddTopic, AddTopicReply ]
managedablePermissions.sort()
managedablePermissions = tuple(managedablePermissions)

role_map = {
    0:forumManager,1:forumReviewer,2:forumWriter,3:replyWriter,4:forumReader }


class PermissionsManagement(Base):

    security = ClassSecurityInfo()

    security.declarePrivate('setCreatePollRolesTopic')
    def setCreatePollRolesTopic(self, value, **kw):
        self.manage_permission(AddPoll, value, 0)
        
    security.declarePrivate('getCreatePollRolesTopic')
    def getCreatePollRolesTopic(self):
        roles = self.rolesOfPermission(AddPoll)
        return [o['name'] for o in roles if o['selected']]

    security.declarePrivate('setAttachRolesTopic')
    def setAttachRolesTopic(self, value, **kwargs):
        self.manage_permission(ModifyTopicAttachments, value, 0)
    
    security.declarePrivate('getAttachRolesTopic')
    def getAttachRolesTopic(self):
        roles = self.rolesOfPermission(ModifyTopicAttachments)
        return [o['name'] for o in roles if o['selected']]

    security.declarePrivate('setAttachRolesReply')
    def setAttachRolesReply(self, value, **kwargs):
        self.manage_permission(ModifyReplyAttachments, value, 0)

    security.declarePrivate('getAttachRolesReply')
    def getAttachRolesReply(self):
        roles = self.rolesOfPermission(ModifyReplyAttachments)
        return [o['name'] for o in roles if o['selected']]

    security.declareProtected(ManageForum, 'getForumGroups')
    def getForumGroups(self):
        """ """
        try:
            groups = self.portal_groups
        except:
            return []

        res = []
        for grp in groups.listGroups():
            res.append((grp.getUserName(), grp.getUserNameWithoutGroupPrefix()))
            
        return res

    # permissions management API
    security.declareProtected(ManageForum, 'getForumRoles')
    def getForumLocalRoles(self):
        """ """
        acl = self.acl_users

        if acl.meta_type == 'Group User Folder':
            return acl.getLocalRolesForDisplay(self)
        else:
            results = []
            for rec in self.get_local_roles():
                results.append(rec + ('user', rec[0]))
            return results

    security.declareProtected(ManageForum, 'delForumRoles')
    def delForumLocalRoles(self, member_ids):
        """ """
        if type(member_ids) == type(''):
            member_ids = (member_ids,)
            
        for member_id in member_ids:
            roles = list(self.get_local_roles_for_userid(member_id))
            for r in roles[:]:
                if r in role_map.values():
                    roles.remove[r]
            if roles:
                self.manage_setLocalRoles( member_id, roles )
            else:
                self.manage_delLocalRoles( (member_id,) )

        # update catalog
        self.notifyStateChanged()

    security.declareProtected(ManageForum, 'setForumRoles')
    def setForumLocalRoles(self, member_ids, role=None):
        """ """
        if role is None:
            return

        role = role_map[int(role)]

        if type(member_ids) == type(''):
            member_ids = (member_ids,)
        
        for member_id in member_ids:
            roles = list(self.get_local_roles_for_userid(member_id))
            for r in roles[:]:
                if r in role_map.values():
                    roles.remove[r]
            roles.append(role)
            self.manage_setLocalRoles( member_id, roles )

        # update catalog
        self.notifyStateChanged()


    # roles permissions management API
    security.declareProtected(ManageForum, 'getForumRoles')
    def getForumRoles(self):
        """ """
        roles = self.portal_membership.getCandidateLocalRoles(self)

        for r in ('Owner', 'Reviewer', 'Manager'):
            try:
                del roles[roles.index(r)]
            except:
                pass

        if 'Anonymous' not in roles:
            roles = ['Anonymous'] + roles

        return roles


InitializeClass(PermissionsManagement)
